@@ -7,7 +7,6 @@ from .example import Example
 from .header import Header
 from .link import Link
 from .parameter import Parameter
-from .path_item import PathItem
 from .reference import Reference
 from .request_body import RequestBody
 from .response import Response
@@ -16,41 +15,39 @@ from .security_scheme import SecurityScheme
 
 
 class Components(BaseModel):
-    """
-    Holds a set of reusable objects for different aspects of the OAS.
-    All objects defined within the components object will have no effect on the API
-    unless they are explicitly referenced from properties outside the components object.
+    """Holds a set of reusable objects for different aspects of the OAS.
+
+    All objects defined within the components object will have no effect
+    on the API unless they are explicitly referenced from properties
+    outside the components object.
     """
 
-    schemas: Optional[Dict[str, Schema]] = None
-    """An object to hold reusable `Schema Objects <https://spec.openapis.org/oas/v3.1.0#schemaObject>`__."""
+    schemas: Optional[Dict[str, Union[Reference, Schema]]] = None
+    """An object to hold reusable [Schema Objects](https://spec.openapis.org/oas/v3.0.3#schemaObject>)."""
 
     responses: Optional[Dict[str, Union[Response, Reference]]] = None
-    """An object to hold reusable `Response Objects <https://spec.openapis.org/oas/v3.1.0#responseObject>`__."""
+    """An object to hold reusable [Response Objects](https://spec.openapis.org/oas/v3.0.3#responseObject)."""
 
     parameters: Optional[Dict[str, Union[Parameter, Reference]]] = None
-    """An object to hold reusable `Parameter Objects <https://spec.openapis.org/oas/v3.1.0#parameterObject>`__."""
+    """An object to hold reusable [Parameter Objects](https://spec.openapis.org/oas/v3.0.3#parameterObject)."""
 
     examples: Optional[Dict[str, Union[Example, Reference]]] = None
-    """An object to hold reusable `Example Objects <https://spec.openapis.org/oas/v3.1.0#exampleObject>`__."""
+    """An object to hold reusable [Example Objects](https://spec.openapis.org/oas/v3.0.3#exampleObject)."""
 
     requestBodies: Optional[Dict[str, Union[RequestBody, Reference]]] = None
-    """An object to hold reusable `Request Body Objects <https://spec.openapis.org/oas/v3.1.0#requestBodyObject>`__."""
+    """An object to hold reusable [Request Body Objects](https://spec.openapis.org/oas/v3.0.3#requestBodyObject)."""
 
     headers: Optional[Dict[str, Union[Header, Reference]]] = None
-    """An object to hold reusable `Header Objects <https://spec.openapis.org/oas/v3.1.0#headerObject>`__."""
+    """An object to hold reusable [Header Objects](https://spec.openapis.org/oas/v3.0.3#headerObject)."""
 
     securitySchemes: Optional[Dict[str, Union[SecurityScheme, Reference]]] = None
-    """An object to hold reusable `Security Scheme Objects <https://spec.openapis.org/oas/v3.1.0#securitySchemeObject>`__."""
+    """An object to hold reusable [Security Scheme Objects](https://spec.openapis.org/oas/v3.0.3#securitySchemeObject)."""
 
     links: Optional[Dict[str, Union[Link, Reference]]] = None
-    """An object to hold reusable `Link Objects <https://spec.openapis.org/oas/v3.1.0#linkObject>`__."""
+    """An object to hold reusable [Link Objects](https://spec.openapis.org/oas/v3.0.3#linkObject)."""
 
     callbacks: Optional[Dict[str, Union[Callback, Reference]]] = None
-    """An object to hold reusable `Callback Objects <https://spec.openapis.org/oas/v3.1.0#callbackObject>`__."""
-
-    pathItems: Optional[Dict[str, Union[PathItem, Reference]]] = None
-    """An object to hold reusable `Path Item Object <https://spec.openapis.org/oas/v3.1.0#pathItemObject>`__."""
+    """An object to hold reusable [Callback Objects](https://spec.openapis.org/oas/v3.0.3#callbackObject)."""
 
     class Config:
         extra = Extra.ignore
