@@ -4,9 +4,7 @@ from pydantic import AnyUrl, BaseModel, EmailStr, Extra, validator
 
 
 class Contact(BaseModel):
-    """
-    Contact information for the exposed API.
-    """
+    """Contact information for the exposed API."""
 
     name: Optional[str] = None
     """
@@ -15,14 +13,12 @@ class Contact(BaseModel):
 
     url: Optional[AnyUrl] = None
     """
-    The URL pointing to the contact information.
-    MUST be in the form of a URL.
+    The URL pointing to the contact information. MUST be in the format of a URL.
     """
 
     email: Optional[Union[EmailStr, str]] = None
     """
-    The email address of the contact person/organization.
-    MUST be in the form of an email address.
+    The email address of the contact person/organization. MUST be in the format of an email address.
     """
 
     @validator("email", pre=True)
@@ -30,16 +26,16 @@ class Contact(BaseModel):
         cls,
         v: Union[EmailStr, str],
     ) -> EmailStr:
-        """Validates that email is a valid email address
+        """Validates that email is a valid email address.
 
         Args:
-            v (EmailStr|str): Holds the email string to be validated
+            v: Holds the email string to be validated
 
         Raises:
             ValueError: Value is not a valid email address
 
         Returns:
-            _type_: CompressionBackend
+            Validated email string.
         """
         if isinstance(v, str):
             v = EmailStr(v)
