@@ -9,13 +9,12 @@ class ExternalDocumentation(BaseModel):
     description: Optional[str] = None
     """
     A short description of the target documentation.
-    `CommonMark syntax <https://spec.commonmark.org/>`__ MAY be used for rich text representation.
+    [CommonMark syntax](https://spec.commonmark.org/) MAY be used for rich text representation.
     """
 
     url: AnyUrl
     """
-    **REQUIRED**. The URL for the target documentation.
-    Value MUST be in the form of a URL.
+    **REQUIRED**. The URL for the target documentation. Value MUST be in the format of a URL.
     """
 
     class Config:
