@@ -5,13 +5,14 @@ from .parameter import Parameter
 
 
 class Header(Parameter):
-    """
-    The Header Object follows the structure of the `Parameter Object <https://spec.openapis.org/oas/v3.0.3#parameterObject>`__ with the following changes:
+    """The Header Object follows the structure of the [Parameter
+    Object](https://spec.openapis.org/oas/v3.0.3#parameterObject) with the
+    following changes:
 
     1. `name` MUST NOT be specified, it is given in the corresponding `headers` map.
     2. `in` MUST NOT be specified, it is implicitly in `header`.
     3. All traits that are affected by the location MUST be applicable to a location of `header`
-       (for example, `style <https://spec.openapis.org/oas/v3.0.3#parameterStyle>`__).
+       (for example, [style](https://spec.openapis.org/oas/v3.0.3#parameterStyle)).
     """
 
     name: Literal[""] = Field(default="", const=True)
