@@ -4,16 +4,13 @@ from pydantic import AnyUrl, BaseModel, Extra
 
 
 class OAuthFlow(BaseModel):
-    """
-    Configuration details for a supported OAuth Flow
-    """
+    """Configuration details for a supported OAuth Flow."""
 
     authorizationUrl: Optional[Union[AnyUrl, str]] = None
     """
     **REQUIRED** for `oauth2 ("implicit", "authorizationCode")`.
     The authorization URL to be used for this flow.
     This MUST be in the form of a URL.
-    The OAuth2 standard requires the use of TLS.
     """
 
     tokenUrl: Optional[Union[AnyUrl, str]] = None
@@ -21,19 +18,16 @@ class OAuthFlow(BaseModel):
     **REQUIRED** for `oauth2 ("password", "clientCredentials", "authorizationCode")`.
     The token URL to be used for this flow.
     This MUST be in the form of a URL.
-    The OAuth2 standard requires the use of TLS.
     """
 
     refreshUrl: Optional[Union[AnyUrl, str]] = None
     """
-    The URL to be used for obtaining refresh tokens.
-    This MUST be in the form of a URL.
-    The OAuth2 standard requires the use of TLS.
+    The URL to be used for obtaining refresh tokens. This MUST be in the form of a URL.
     """
 
-    scopes: Optional[Dict[str, str]] = None
+    scopes: Dict[str, str]
     """
-    **REQUIRED** for `oauth2`. The available scopes for the OAuth2 security scheme.
+    **REQUIRED**. The available scopes for the OAuth2 security scheme.
     A map between the scope name and a short description for it.
     The map MAY be empty.
     """
