@@ -4,7 +4,8 @@ from pydantic import BaseModel, Extra
 
 
 class ServerVariable(BaseModel):
-    """An object representing a Server Variable for server URL template substitution."""
+    """An object representing a Server Variable for server URL template
+    substitution."""
 
     enum: Optional[List[str]] = None
     """
@@ -16,15 +17,15 @@ class ServerVariable(BaseModel):
     """
     **REQUIRED**. The default value to use for substitution,
     which SHALL be sent if an alternate value is _not_ supplied.
-    Note this behavior is different than the `Schema Object's <https://spec.openapis.org/oas/v3.0.3#schemaObject>`__ treatment of default values,
+    Note this behavior is different than the [Schema Object's](https://spec.openapis.org/oas/v3.0.3#schemaObject) treatment of default values,
     because in those cases parameter values are optional.
-    If the `enum <https://spec.openapis.org/oas/v3.0.3#serverVariableEnum>`__ is defined, the value SHOULD exist in the enum's values.
+    If the [enum](https://spec.openapis.org/oas/v3.0.3#serverVariableEnum) is defined, the value SHOULD exist in the enum's values.
     """
 
     description: Optional[str] = None
     """
     An optional description for the server variable.
-    `CommonMark syntax <https://spec.commonmark.org/>`__ MAY be used for rich text representation.
+    [CommonMark syntax](https://spec.commonmark.org/) MAY be used for rich text representation.
     """
 
     class Config:
